# CountESS 0.0.54

This is CountESS, a modular, Python 3 reimplementation of Enrich2.

## License

BSD 3-clause.  See [LICENSE.txt](LICENSE.txt)

Source code is available at [https://github.com/CountESS-Project/CountESS](https://github.com/CountESS-Project/CountESS) and contributions are welcomed.

## Installing

The latest version of CountESS can be installed from pypi:
```
pip install CountESS
```

For other options, see the documentation below ...

## Documentation

[CountESS Documentation](https://countess-project.github.io/CountESS/)

## Enquiries

Please contact Alan Rubin `alan@rubin.id.au` for further information or
Nick Moore `nick@zoic.org` for code-related matters.
